@@ -199,6 +199,8 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     action_group()->add( Gtk::Action::create( "OpenTab", "タブで開く(_T)"), sigc::mem_fun( *this, &BBSListViewBase::slot_open_tab ) );
     action_group()->add( Gtk::Action::create( "OpenBrowser", ITEM_NAME_OPEN_BROWSER + std::string( "(_W)" ) ),
                          sigc::mem_fun( *this, &BBSListViewBase::slot_open_browser ) );
+    action_group()->add( Gtk::Action::create( "OpenCacheBrowser", ITEM_NAME_OPEN_CACHE_BROWSER + std::string( "(_X)" ) ),
+                         sigc::mem_fun( *this, &BBSListViewBase::slot_open_cache_browser ) );
     action_group()->add( Gtk::Action::create( "AppendFavorite", "AppendFavorite"), sigc::mem_fun( *this, &BBSListViewBase::slot_append_favorite ) );
     action_group()->add( Gtk::Action::create( "NewDir", "新規ディレクトリ(_N)"), sigc::mem_fun( *this, &BBSListViewBase::slot_newdir ) );
     action_group()->add( Gtk::Action::create( "NewCom", "コメント挿入(_I)"), sigc::mem_fun( *this, &BBSListViewBase::slot_newcomment ) );
@@ -309,6 +311,7 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     "<popup name='popup_menu_favorite'>"
     "<menuitem action='OpenTab'/>"
     "<menuitem action='OpenBrowser'/>"
+    "<menuitem action='OpenCacheBrowser'/>"
     "<separator/>"
     POPUPMENU_SELECT
     "</popup>"
@@ -410,6 +413,7 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     "<separator/>" \
     "<menuitem action='PreferenceArticle'/>" \
     "<menuitem action='PreferenceBoard'/>" \
+    "<menuitem action='PreferenceImage'/>" \
     "</popup>"
 
     // 履歴 + 複数選択
@@ -509,6 +513,12 @@ BBSListViewBase::~BBSListViewBase()
 }
 
 
+void BBSListViewBase::save_session()
+{
+    save_xml();
+}
+
+
 SKELETON::Admin* BBSListViewBase::get_admin()
 {
     return BBSLIST::get_admin();
@@ -542,9 +552,10 @@ const bool BBSListViewBase::set_command( const std::string& command, const std::
     if( command == "append_item" ) append_item();
     else if( command == "append_history" ) append_history();
     else if( command == "remove_item" ) remove_item( arg1 );
+    else if( command == "remove_headitem" ) remove_headitem();
     else if( command == "remove_allitems" ) remove_allitems();
     else if( command == "edit_tree" ) edit_tree();
-    else if( command == "save_xml" ) save_xml( false );
+    else if( command == "save_xml" ) save_xml(); 
     else if( command == "toggle_articleicon" ) toggle_articleicon( arg1 );
     else if( command == "toggle_boardicon" ) toggle_boardicon( arg1 );
     else if( command == "replace_thread" ) replace_thread( arg1, arg2 );
@@ -559,19 +570,6 @@ const bool BBSListViewBase::set_command( const std::string& command, const std::
 }
 
 
-//
-// shutdown( SIGHUP )用
-//
-void BBSListViewBase::shutdown()
-{
-#ifdef _DEBUG    
-    std::cout << "BBSListViewBase::shutdown\n";
-#endif
-
-    save_xml( true );
-}
-
-
 //
 // クロック入力
 //
@@ -731,6 +729,8 @@ void BBSListViewBase::update_item( const std::string& url, const std::string& id
 //
 const bool BBSListViewBase::operate_view( const int control )
 {
+    if( CONTROL::operate_common( control, get_url(), BBSLIST::get_admin() ) ) return true;
+
     Gtk::TreePath path = m_treeview.get_current_path();
     Gtk::TreeModel::Row row;
     bool open_tab = false;
@@ -757,6 +757,14 @@ const bool BBSListViewBase::operate_view( const int control )
             page_down();
             break;
 
+        case CONTROL::PrevDir:
+            prev_dir();
+            break;
+
+        case CONTROL::NextDir:
+            next_dir();
+            break;
+
         case CONTROL::Home:
             goto_top();
             break;
@@ -826,53 +834,6 @@ const bool BBSListViewBase::operate_view( const int control )
             CORE::core_set_command( "toggle_article" );
             break;
 
-        case CONTROL::TabLeft:
-        case CONTROL::TabLeftUpdated:
-            BBSLIST::get_admin()->set_command( "tab_left" );
-            break;
-
-        case CONTROL::TabRight:
-        case CONTROL::TabRightUpdated:
-            BBSLIST::get_admin()->set_command( "tab_right" );
-            break;
-
-        // タブ位置(1-9)で移動
-        case CONTROL::TabNum1:
-            BBSLIST::get_admin()->set_command( "tab_num", "", "1" );
-            break;
-
-        case CONTROL::TabNum2:
-            BBSLIST::get_admin()->set_command( "tab_num", "", "2" );
-            break;
-
-        case CONTROL::TabNum3:
-            BBSLIST::get_admin()->set_command( "tab_num", "", "3" );
-            break;
-
-        case CONTROL::TabNum4:
-            BBSLIST::get_admin()->set_command( "tab_num", "", "4" );
-            break;
-
-        case CONTROL::TabNum5:
-            BBSLIST::get_admin()->set_command( "tab_num", "", "5" );
-            break;
-
-        case CONTROL::TabNum6:
-            BBSLIST::get_admin()->set_command( "tab_num", "", "6" );
-            break;
-
-        case CONTROL::TabNum7:
-            BBSLIST::get_admin()->set_command( "tab_num", "", "7" );
-            break;
-
-        case CONTROL::TabNum8:
-            BBSLIST::get_admin()->set_command( "tab_num", "", "8" );
-            break;
-
-        case CONTROL::TabNum9:
-            BBSLIST::get_admin()->set_command( "tab_num", "", "9" );
-            break;
-
         // 終了
         case CONTROL::Quit:
             close_view();
@@ -915,30 +876,6 @@ const bool BBSListViewBase::operate_view( const int control )
             up_search();
             break;
 
-            // サイドバー表示/非表示
-        case CONTROL::ShowSideBar:
-            CORE::core_set_command( "toggle_sidebar" );
-            break;
-
-            // メニューバー表示/非表示
-        case CONTROL::ShowMenuBar:
-            CORE::core_set_command( "toggle_menubar" );
-            break;
-
-            // メインツールバー表示/非表示
-        case CONTROL::ShowToolBarMain:
-            CORE::core_set_command( "toggle_toolbarmain" );
-            break;
-
-            // サイドバー更新チェック
-        case CONTROL::CheckUpdateRoot:
-            CORE::core_set_command( "check_update_root" );
-            break;
-
-        case CONTROL::CheckUpdateOpenRoot:
-            CORE::core_set_command( "check_update_open_root" );
-            break;
-
         case CONTROL::StopLoading:
             CORE::core_set_command( "cancel_check_update" );
             break;
@@ -951,11 +888,6 @@ const bool BBSListViewBase::operate_view( const int control )
             redo();
             break;
 
-            // URLを開くダイアログを表示
-        case CONTROL::OpenURL:
-            CORE::core_set_command( "show_openurl_diag" );
-            break;
-
         default:
             return false;
     }
@@ -972,12 +904,13 @@ const bool BBSListViewBase::operate_view( const int control )
 //
 void BBSListViewBase::activate_act_before_popupmenu( const std::string& url )
 {
-    Glib::RefPtr< Gtk::Action > act_search, act_import, act_board, act_article, act_image, act_opentab;
+    Glib::RefPtr< Gtk::Action > act_search, act_import, act_board, act_article, act_image, act_opencache, act_opentab;
     act_search = action_group()->get_action( "SearchCacheBoard" );
     act_import = action_group()->get_action( "ImportDat" );
     act_board = action_group()->get_action( "PreferenceBoard" );
     act_article = action_group()->get_action( "PreferenceArticle" );
     act_image = action_group()->get_action( "PreferenceImage" );
+    act_opencache = action_group()->get_action( "OpenCacheBrowser" );
     act_opentab = action_group()->get_action( "OpenTab" );
 
     if( act_search ) act_search->set_sensitive( false );
@@ -985,6 +918,7 @@ void BBSListViewBase::activate_act_before_popupmenu( const std::string& url )
     if( act_board ) act_board->set_sensitive( false );
     if( act_article ) act_article->set_sensitive( false );
     if( act_image ) act_image->set_sensitive( false );
+    if( act_opencache ) act_opencache->set_sensitive( false );
     if( act_opentab ) act_opentab->set_sensitive( true );
 
     int type = path2type( m_path_selected );
@@ -1005,6 +939,7 @@ void BBSListViewBase::activate_act_before_popupmenu( const std::string& url )
 
         case TYPE_IMAGE:
             if( act_image && ! DBIMG::get_abone( url ) ) act_image->set_sensitive( true );
+            if( act_opencache && DBIMG::is_cached( url ) ) act_opencache->set_sensitive( true );
             break;
 
         case TYPE_DIR:
@@ -1082,6 +1017,23 @@ void BBSListViewBase::page_down()
 } 
 
 
+//
+// 前のディレクトリに移動
+//
+void BBSListViewBase::prev_dir()
+{
+    m_treeview.prev_dir();
+}
+
+//
+// 次のディレクトリに移動
+//
+void BBSListViewBase::next_dir()
+{
+    m_treeview.next_dir();
+}
+
+
 //
 // 他のviewのtreestoreをcopyして表示
 //
@@ -1343,7 +1295,8 @@ void BBSListViewBase::slot_dropped_from_other( const CORE::DATA_INFO_LIST& list_
 
             case TYPE_IMAGE:
 
-                DBIMG::set_protect( info.url, true );
+                if( m_set_bookmark ) DBIMG::set_protect( info.url, true );
+                m_set_image.insert( info.url );
                 break;
         }
     }
@@ -1373,6 +1326,21 @@ void BBSListViewBase::slot_open_browser()
 }
 
 
+//
+// 画像キャッシュをブラウザで開く
+//
+void BBSListViewBase::slot_open_cache_browser()
+{
+    if( m_path_selected.empty() ) return;
+
+    std::string url = path2url( m_path_selected );
+    if( ! DBIMG::is_cached( url ) ) return;
+
+    url = "file://" + DBIMG::get_cache_path( url );
+    CORE::core_set_command( "open_url_browser", url );
+}
+
+
 //
 // 選択行をお気に入りに追加
 //
@@ -1570,7 +1538,7 @@ void BBSListViewBase::add_newetcboard( const bool move, // true なら編集モ
             const bool scroll = false;
             const bool force = true;  // 強制的に追加
             const bool cancel_undo_commit = false;
-            const bool check_dup = false;
+            const int check_dup = 0; // 項目の重複チェックをしない
             m_treeview.append_info( list_info, m_path_selected, before, scroll, force, cancel_undo_commit, check_dup );
             m_path_selected = m_treeview.get_current_path();
 
@@ -1974,7 +1942,7 @@ const bool BBSListViewBase::open_row( Gtk::TreePath& path, const bool tab )
 
     // treeviewが編集されていたらxml保存
     if( type != TYPE_DIR && m_treeview.is_updated() ){
-        save_xml( false );
+        save_xml();
         m_treeview.set_updated( false );
     }
 
@@ -2284,6 +2252,7 @@ void BBSListViewBase::tree2xml( const std::string& root_name )
     // ルート要素に属性( path, y )の値を設定
     XML::Dom* root = m_document.get_root_element( root_name );
     if( root ){
+        if( ! m_date_modified.empty() ) root->setAttribute( "date_modified", m_date_modified );
         root->setAttribute( "y", y );
         root->setAttribute( "path", path );
     }
@@ -2316,7 +2285,8 @@ void BBSListViewBase::xml2tree( const std::string& root_name, const std::string&
     XML::Dom* root = m_document.get_root_element( root_name );
     if( root ){
 
-	// ルート要素から属性( path, y )の値を取得
+	// ルート要素から属性( date_modified, path, y )の値を取得
+	m_date_modified = root->getAttribute( "date_modified" );
 	std::string focused_path = root->getAttribute( "path" );
 	int y = atoi( root->getAttribute( "y" ).c_str() );
 
@@ -2365,6 +2335,7 @@ void BBSListViewBase::update_urls()
 
     m_set_board.clear();
     m_set_thread.clear();
+    m_set_image.clear();
     
     SKELETON::EditTreeViewIterator it( m_treeview, m_columns, Gtk::TreePath() );
     for( ; ! it.end(); ++it ){
@@ -2414,6 +2385,10 @@ void BBSListViewBase::update_urls()
 
                 m_set_thread.insert( url_new );
                 break;
+
+            case TYPE_IMAGE:
+                m_set_image.insert( url );
+                break;
         }
     }
 
@@ -2421,7 +2396,7 @@ void BBSListViewBase::update_urls()
     DBTREE::set_enable_save_movetable( true );
 
     if( updated ){
-        save_xml( false );
+        save_xml();
         DBTREE::save_movetable();
     }
 }
@@ -2807,17 +2782,25 @@ void BBSListViewBase::append_item()
     // バックアップを取っておく
     CORE::DATA_INFO_LIST list_info_bkup = CORE::SBUF_list_info();
 
-    // 挿入先ダイアログ表示
-    Gtk::Window* parent = ( *list_info_bkup.begin() ).parent;
-    SelectListDialog diag( parent, get_url(), get_treestore() );
-    if( diag.run() != Gtk::RESPONSE_OK ) return;
+    std::string path_str;
+
+    const int show_diag = CONFIG::get_show_favorite_select_diag();
+    if( show_diag == 1 ) path_str = "-1";
+    else if( show_diag == 2 ) path_str = "";
+    else{
+
+        // 挿入先ダイアログ表示
+        Gtk::Window* parent = ( *list_info_bkup.begin() ).parent;
+        SelectListDialog diag( parent, get_url(), get_treestore() );
+        if( diag.run() != Gtk::RESPONSE_OK ) return;
+
+        path_str = diag.get_path();
+        if( list_info_bkup.size() == 1 && ! diag.get_name().empty() ) ( *list_info_bkup.begin() ).name = diag.get_name();
+    }
 
     bool before = false;
     Gtk::TreePath path;
 
-    const std::string path_str = diag.get_path();
-    if( list_info_bkup.size() == 1 && ! diag.get_name().empty() ) ( *list_info_bkup.begin() ).name = diag.get_name();
-
     // 先頭
     if( path_str == "-1" ){
         path = Gtk::TreePath( "0" );
@@ -2831,7 +2814,7 @@ void BBSListViewBase::append_item()
     const bool scroll = true;
     const bool force = false;
     const bool cancel_undo_commit = false;
-    const bool check_dup = true; // 重複チェック
+    const int check_dup = CONFIG::get_check_favorite_dup(); // 重複チェックするか
 
     const CORE::DATA_INFO_LIST list_info = m_treeview.append_info( list_info_bkup, path, before, scroll, force, cancel_undo_commit, check_dup );
     CORE::SBUF_clear_info();
@@ -2863,7 +2846,9 @@ void BBSListViewBase::append_history()
     // ツリーにアイテムが含まれている場合は削除
     // 履歴はサブディレクトリが無いと仮定してサブディレクトリの探査はしない
     if( ( ( *it_info ).type == TYPE_THREAD && m_set_thread.find_if( ( *it_info ).url ) ) 
-        || ( ( ( *it_info ).type == TYPE_BOARD || ( *it_info ).type == TYPE_VBOARD )  && m_set_board.find( ( *it_info ).url ) != m_set_board.end() ) ){
+        || ( ( ( *it_info ).type == TYPE_BOARD || ( *it_info ).type == TYPE_VBOARD )  && m_set_board.find( ( *it_info ).url ) != m_set_board.end() )
+        || ( ( *it_info ).type == TYPE_IMAGE && m_set_image.find( ( *it_info ).url ) != m_set_image.end() ) 
+        ){
 
         std::vector< Gtk::TreePath > del_path;
 
@@ -2981,6 +2966,7 @@ void BBSListViewBase::remove_item( const std::string& url )
 {
     std::string url_target = DBTREE::url_dat( url );
     if( url_target.empty() ) url_target = DBTREE::url_boardbase( url );
+    if( url_target.empty() && DBIMG::get_type_ext( url ) != DBIMG::T_UNKNOWN ) url_target = url;
     if( url_target.empty() ) return;
         
 #ifdef _DEBUG
@@ -3005,6 +2991,8 @@ void BBSListViewBase::remove_item( const std::string& url )
             case TYPE_THREAD_UPDATE:
             case TYPE_THREAD_OLD:
 
+            case TYPE_IMAGE: // 画像
+
                 if( url == url_target ){
 #ifdef _DEBUG
                     std::cout << "hit " << url << " == " << url_target << std::endl;
@@ -3021,6 +3009,27 @@ void BBSListViewBase::remove_item( const std::string& url )
 }
 
 
+//
+// 先頭項目を削除
+//
+void BBSListViewBase::remove_headitem()
+{
+    if( ! m_ready_tree ) return;
+    if( m_treestore->children().empty() ) return;
+
+#ifdef _DEBUG
+    std::cout << "BBSListViewBase::remove_headitem\n";
+#endif
+
+    std::list< Gtk::TreePath > list_path;
+    SKELETON::EditTreeViewIterator it( m_treeview, m_columns, Gtk::TreePath() );
+    list_path.push_back( it.get_path() );
+
+    const bool force = true;
+    m_treeview.delete_path( list_path, force );
+}
+
+
 //
 // 全項目を削除
 //
@@ -3033,6 +3042,7 @@ void BBSListViewBase::remove_allitems()
     m_treestore->clear();
     m_set_board.clear();
     m_set_thread.clear();
+    m_set_image.clear();
 }
 
 
