@@ -24,23 +24,31 @@ namespace CONFIG
         CONF_PROXY_PORT_FOR2CH_W = 8080, // 2ch 書き込み用プロクシポート番号
         CONF_USE_PROXY_FOR_DATA = 0, // 2ch 以外にアクセスするときにプロクシを使用するか
         CONF_PROXY_PORT_FOR_DATA = 8080, // 2ch 以外にアクセスするときのプロクシポート番号
-        CONF_LOADER_BUFSIZE = 32,   // ローダのバッファサイズ
+        CONF_LOADER_BUFSIZE = 32,   // ローダのバッファサイズ (一般)
+        CONF_LOADER_BUFSIZE_BOARD = 2,   // ローダのバッファサイズ (スレ一覧用)
         CONF_LOADER_TIMEOUT = 10,   // ローダのタイムアウト値        
         CONF_LOADER_TIMEOUT_POST = 30, // ポストローダのタイムアウト値        
         CONF_LOADER_TIMEOUT_IMG = 30,  // 画像ローダのタイムアウト値
         CONF_LOADER_TIMEOUT_CHECKUPDATE = 10,  // 更新チェックのタイムアウト値
         CONF_USE_IPV6 = 1,          // ipv6使用
+        CONF_CONNECTION_NUM = 2,    // 同一ホストに対する最大コネクション数( 1 または 2 )
         CONF_REFPOPUP_BY_MO = 0,    // レス番号の上にマウスオーバーしたときに参照ポップアップ表示する
         CONF_NAMEPOPUP_BY_MO = 0,   // 名前の上にマウスオーバーしたときにポップアップ表示する
         CONF_IDPOPUP_BY_MO = 0,     // IDの上にマウスオーバーしたときにIDをポップアップ表示する
         CONF_USE_TREE_GTKRC = 0,    // ツリービューでgtkrcの設定を使用するか
         CONF_USE_SELECT_GTKRC = 0,  // スレビューの選択色でgtkrcの設定を使用するか
         CONF_TREE_YPAD = 1,         // ツリービューの行間スペース
+        CONF_TREE_SHOW_EXPANDERS = 1, // ツリービューにエクスパンダを表示
+        CONF_TREE_LEVEL_INDENT = 0, // ツリービューのレベルインデント調整量(ピクセル)
+        CONF_SCROLL_TREE = 1,       // カテゴリを開いたときにツリービューをスクロールする
         CONF_VIEW_MARGIN = 0,       // 各ビューと枠との間の余白
+        CONF_LEFT_SCRBAR = 0,       // スクロールバーを左に配置
         CONF_SHOW_OLDARTICLE = 0,   // スレ一覧で古いスレも表示
         CONF_NEWTHREAD_HOUR = 24,   // スレ一覧で指定した値(時間)よりも後に立てられたスレを新着とみなす
         CONF_INC_SEARCH_BOARD = 0,  // スレ一覧でインクリメント検索をする
         CONF_SHOW_DELDIAG = 1 ,     // スレ一覧でdeleteを押したときに確認ダイアログを表示する
+        CONF_SHOW_CACHED_BOARD = 1, // スレ一覧をロードする前にキャッシュにある一覧を表示
+        CONF_SHOW_924 = 1,          // スレ一覧でお知らせスレ(924)のアイコンを表示する
         CONF_TREE_SCROLL_SIZE = 4,  // ツリービューのスクロール量(行数)
         CONF_SCROLL_SIZE = 3,       // スレビューのスクロール量
         CONF_KEY_SCROLL_SIZE = 2,   // スレビューのスクロール量(キー上下)
@@ -56,10 +64,18 @@ namespace CONFIG
         CONF_SAVE_POSTHIST = 1,      //書き込み履歴を保存
         CONF_MAXSIZE_POSTLOG = ( 256 * 1024 ), // 書き込みログの最大サイズ
         CONF_HIDE_WRITING_DIALOG = 0, // 「書き込み中」のダイアログを表示しない
+        CONF_SHOW_SAVEMSGDIAG = 1,  // 編集中のメッセージの保存確認ダイアログを表示する
+        CONF_MESSAGE_WRAP = 1,      // 書き込みビューでテキストを折り返す
         CONF_FOLD_MESSAGE = 0,      // 非アクティブ時に書き込みビューを折りたたむ
-        CONF_MARGIN_POPUP = 30,     // レスアンカーとポップアップの間のマージン
-        CONF_MARGIN_IMGPOPUP = CONF_MARGIN_POPUP,  // レスアンカーと画像ポップアップの間のマージン
+        CONF_FOLD_IMAGE = 1,        // 非アクティブ時に画像ビューを折りたたむ
+        CONF_KEEP_IM_STATUS = 0,    // 書き込み欄の日本語のON/OFF状態を保存
+        CONF_MARGIN_POPUP = 30,     // レスアンカーとポップアップの間のマージン ( 垂直方向 )
+        CONF_MARGIN_IMGPOPUP_X = 0, // レスアンカーと画像ポップアップの間のマージン ( 水平方向 )
+        CONF_MARGIN_IMGPOPUP = CONF_MARGIN_POPUP,  // レスアンカーと画像ポップアップの間のマージン ( 垂直方向 )
+        CONF_HIDE_POPUP_MSEC = 0,   // ポップアップが消えるまでの時間(ミリ秒)
+        CONF_ENABLE_MG = 1,         // マウスジェスチャを有効
         CONF_MOUSE_RADIUS = 25,     // マウスジェスチャの判定開始半径
+        CONF_NUMBERJMP_MSEC = 1000, // 数字入力ジャンプの待ち時間(ミリ秒)
         CONF_HISTORY_SIZE = 20,      // 履歴メニューの表示数
         CONF_HISTORYVIEW_SIZE = 100, // 履歴ビューの表示数
         CONF_AAHISTORY = 7,         // AA履歴の保持数
@@ -92,6 +108,9 @@ namespace CONFIG
         CONF_USE_IMAGE_VIEW = 1,    // 画像ビューを使用する
         CONF_INLINE_IMG = 0,        // インライン画像を表示する
         CONF_SHOW_SSSPICON = 1,     // sssp アイコン表示
+        CONF_EMBIMG_WIDTH = 100, // インライン画像の最大幅
+        CONF_EMBIMG_HEIGHT = 100, // インライン画像の最大高さ
+        CONF_SHOW_DELIMGDIAG = 1 ,     // 画像ビューでdeleteを押したときに確認ダイアログを表示する
         CONF_USE_MOSAIC = 1,        // 画像にモザイクをかける
         CONF_MOSAIC_SIZE = 60,        // モザイクの大きさ
         CONF_ZOOM_TO_FIT = 1,       // 画像をデフォルトでウィンドウサイズに合わせる
@@ -102,20 +121,30 @@ namespace CONFIG
         CONF_IMGCACHE_SIZE = 3,      // 画像のメモリキャッシュ枚数
         CONF_USE_LINK_AS_BOARD = 0,     // bbsmenu.html内にあるリンクは全て板とみなす
         CONF_SHOW_MOVEDIAG = 1,    // 板移転時に確認ダイアログを表示する
+        CONF_REMOVE_OLD_ABONE_THREAD = 0, // dat落ちしたスレをNGスレタイトルリストから取り除くか( 0: ダイアログ表示 1: 取り除く 2: 除かない )
         CONF_ABONE_NUMBER_THREAD = 0, // スレあぼーん( レス数 )
         CONF_ABONE_HOUR_THREAD = 0,   // スレあぼーん( スレ立てからの経過時間 )
         CONF_ABONE_TRANSPARENT = 0, // デフォルトで透明あぼーんをする
         CONF_ABONE_CHAIN = 0,       // デフォルトで連鎖あぼーんをする
         CONF_EXPAND_SIDEBAR = 0,      // 右ペーンが空の時にサイドバーを閉じる
         CONF_EXPAND_RPANE = 1,        // 3ペーン時にスレ一覧やスレビューを最大化する
+        CONF_OPEN_SIDEBAR_BY_CLICK = 1, // ペーンの境界をクリックしてサイドバーを開け閉めする
         CONF_THRESHOLD_NEXT = 5,   // 次スレ検索の類似度のしきい値
         CONF_REPLACE_FAVORITE_NEXT = 1,  // 次スレを開いたときにお気に入りのアドレスと名前を自動更新
         CONF_SHOW_DIAG_REPLACE_FAVORITE = 1, // お気に入りの自動更新をするかダイアログを出す
         CONF_BOOKMARK_DROP = 0, // スレをお気に入りに追加したときにしおりをセットする
         CONF_CHECK_UPDATE_BOARD = 0,  // お気に入りの更新チェック時に板の更新もチェックする
         CONF_CHECK_UPDATE_BOOT = 0,  // 起動時にお気に入りを自動でチェックする
+        CONF_CHECK_FAVORITE_DUP = 1, // お気に入り登録時に重複項目を登録するか ( 0: 登録する 1: ダイアログ表示 2: 登録しない )
+        CONF_SHOW_FAVORITE_SELECT_DIAG = 0, // お気に入り登録時に挿入先ダイアログを表示する ( 0 : 表示する 1: 表示せず先頭に追加 2: 表示せず最後に追加 )
         CONF_DISABLE_CLOSE = 0, // Ctrl+qでウィンドウを閉じない
+        CONF_SHOW_HIDE_MENUBAR_DIAG = 1, // メニューバーを非表示にした時にダイアログを表示
+        CONF_CHANGE_STASTATUS_COLOR = 1, // 状態変更時にメインステータスバーの色を変える
         CONF_USE_MACHI_OFFLAW = 0, // まちBBSの取得に offlaw.cgi を使用する
+        CONF_SHOW_DEL_WRITTEN_THREAD_DIAG = 1, // 書き込み履歴のあるスレを削除する時にダイアログを表示
+        CONF_DELETE_IMG_IN_THREAD = 0, // スレを削除する時に画像キャッシュも削除する ( 0: ダイアログ表示 1: 削除 2: 削除しない )
+        CONF_SHOW_DIAG_FIFO_ERROR = 1, // FIFOの作成などにエラーがあったらダイアログを表示する
+        CONF_SAVE_SESSION = 0, // 指定した分ごとにセッションを自動保存 (0: 保存しない)
     };
 
 // browsers.cpp のデフォルトのラベル番号
@@ -159,6 +188,9 @@ namespace CONFIG
 // p2の認証サーバのアドレス
 #define CONF_LOGINP2 "http://p2.2ch.net/p2/"
 
+// BEの認証サーバのアドレス
+#define CONF_LOGINBE "http://be.2ch.net/test/login.php"
+
 // bbsmenu.htmlのURL
 #define CONF_URL_BBSMENU "http://menu.2ch.net/bbsmenu.html"
 
