@@ -69,13 +69,15 @@ namespace CONTROL
         { "CloseAllTabs", "全てのタブを閉じる" },
         { "CloseOtherTabs", "他のタブを閉じる" },
 
+        { "RestoreLastTab", "最後に閉じたタブを復元" },
+
         { "CheckUpdateTabs", "全ての更新されたタブを再読み込み" },
 
         { "PreBookMark", "前のしおりヘ移動" },
         { "NextBookMark", "次のしおりヘ移動" },
 
-        { "PrevView", ITEM_NAME_PREVVIEW },
-        { "NextView", ITEM_NAME_NEXTVIEW },
+        { "PrevView", ITEM_NAME_BACK },
+        { "NextView", ITEM_NAME_FORWARD },
 
         { "ToggleArticle", "スレ一覧とスレビュー切替" },
 
@@ -108,7 +110,7 @@ namespace CONTROL
         { "OpenURL", "URLを開く..." },        
         { "Copy", ITEM_NAME_COPY },
         { "SelectAll", "全て選択" },
-        { "AppendFavorite", ITEM_NAME_FAVORITE "..." },
+        { "AppendFavorite", ITEM_NAME_APPENDFAVORITE "..." },
         { "Property", "プロパティ..." },
         { "Lock", ITEM_NAME_LOCK },
 
@@ -262,6 +264,7 @@ namespace CONTROL
         { "Preview", ITEM_NAME_PREVIEW },
 
         { "FocusWrite", "書き込みボタンにフォーカスを移す" },
+        { "ToggleSage", "sageのON/OFF切り替え" },
 
         { "", "" },
 
