@@ -40,10 +40,6 @@ struct XSMPDATA
 };
 #endif
 
-#ifdef _WIN32
-#include <windows.h>
-#endif
-
 enum
 {
     MAX_SAFE_ARGC = 4,   // 引数の数の制限値
@@ -54,30 +50,36 @@ JDWinMain* Win_Main = NULL;
 
 
 // バックアップ復元
-void restore_bkup()
+void restore_bkup( const bool no_restore_bkup )
 {
     struct timeval tv;
     struct timezone tz;
     gettimeofday( &tv, &tz );
 
-    std::string path_main = CACHE::path_xml_listmain();
-    std::string path_favor = CACHE::path_xml_favorite();
-    std::string path_main_bkup = CACHE::path_xml_listmain_bkup();
-    std::string path_favor_bkup = CACHE::path_xml_favorite_bkup();
-    std::string path_main_old = path_main + "." + MISC::itostr( tv.tv_sec );
-    std::string path_favor_old = path_favor + "." + MISC::itostr( tv.tv_sec );
+    const std::string path_main = CACHE::path_xml_listmain();
+    const std::string path_favor = CACHE::path_xml_favorite();
+    const std::string path_main_bkup = CACHE::path_xml_listmain_bkup();
+    const std::string path_favor_bkup = CACHE::path_xml_favorite_bkup();
+    const std::string path_main_old = path_main + "." + MISC::itostr( tv.tv_sec );
+    const std::string path_favor_old = path_favor + "." + MISC::itostr( tv.tv_sec );
 
-    bool bkup_main = ( CACHE::file_exists( path_main_bkup ) == CACHE::EXIST_FILE );
-    bool bkup_favor = ( CACHE::file_exists( path_favor_bkup ) == CACHE::EXIST_FILE );
+    const bool bkup_main = ( CACHE::file_exists( path_main_bkup ) == CACHE::EXIST_FILE );
+    const bool bkup_favor = ( CACHE::file_exists( path_favor_bkup ) == CACHE::EXIST_FILE );
 
     if( bkup_main || bkup_favor ){
 
-        Gtk::MessageDialog* mdiag
-        = new Gtk::MessageDialog( "前回の起動時に正しくJDが終了されませんでした。\n\n板リストとお気に入りをバックアップファイルから復元しますか？\nいいえを押すとバックアップファイルを削除します。",
-                                  false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-        int ret = mdiag->run();
-        delete mdiag;
-        if( ret == Gtk::RESPONSE_YES ){
+        bool restore = false;
+
+        if( ! no_restore_bkup ){
+
+            Gtk::MessageDialog* mdiag
+            = new Gtk::MessageDialog( "前回の起動時に正しくJDが終了されませんでした。\n\n板リストとお気に入りをバックアップファイルから復元しますか？\nいいえを押すとバックアップファイルを削除します。",
+                                      false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            if( mdiag->run() == Gtk::RESPONSE_YES ) restore = true;
+            delete mdiag;
+        }
+
+        if( restore ){
 
             if( bkup_main ){
                 rename( path_main.c_str(), path_main_old.c_str() );
@@ -95,7 +97,7 @@ void restore_bkup()
 
             msg += "\nに移動しました。";
 
-            mdiag = new Gtk::MessageDialog( msg );
+            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( msg );
             mdiag->run();
             delete mdiag;
         }
@@ -120,7 +122,7 @@ void sig_handler( int sig )
 #ifdef _DEBUG
         std::cout << "sig_handler sig = " << sig << std::endl;
 #endif
-        if( Win_Main ) Win_Main->shutdown();
+        if( Win_Main ) Win_Main->save_session();
     }
 
     exit(0);
@@ -299,14 +301,16 @@ void usage( const int status )
     // -h, --help で表示するメッセージ
     std::stringstream help_message;
     help_message <<
-    "Usage: jd [option] [<url>]\n"
+    "Usage: jd [OPTION] [URL,FILE]\n"
     "\n"
     "-h, --help\n"
     "        Display this information\n"
     //"-t <url>, --tab=<url>\n"
     //"        URL open of BBS etc by Tab\n"
     "-m, --multi\n"
-    "        Does not terminate even if it is a subprocess\n"
+    "        Do not quit even if multiple sub-process\n"
+    "-n, --norestore\n"
+    "        Do not restore backup files\n"
     "-s, --skip-setup\n"
     "        Skip the setup dialog\n"
     "-l, --logfile\n"
@@ -344,12 +348,13 @@ int main( int argc, char **argv )
 
     // "現在のタブ/新規タブ"など引数によって開き方を変えたい場合は、--tab=<url>
     // など新しいオプションを追加する
-    // --help, --tab=<url>, --multi, --logfile --version
+    // --help, --tab=<url>, --multi, --norestore, --logfile --version
     const struct option options[] =
     {
         { "help", 0, 0, 'h' },
         //{ "tab", 1, 0, 't' },
         { "multi", 0, 0, 'm' },
+        { "norestore", 0, 0, 'n' },
         { "skip-setup", 0, 0, 's' },
         { "logfile", 0, 0, 'l' },
         { "version", 0, 0, 'V' },
@@ -358,12 +363,13 @@ int main( int argc, char **argv )
 
     std::string url;
     bool multi_mode = false;
+    bool no_restore_bkup = false;
     bool skip_setupdiag = false;
     bool logfile_mode = false;
 
-    // -h, -t <url>, -m, -s, -l, -V
+    // -h, -t <url>, -m, -n, -s, -l, -V
     int opt = 0;
-    while( ( opt = getopt_long( argc, argv, "ht:mslV", options, NULL ) ) != -1 )
+    while( ( opt = getopt_long( argc, argv, "ht:mnslV", options, NULL ) ) != -1 )
     {
         switch( opt )
         {
@@ -376,7 +382,13 @@ int main( int argc, char **argv )
                 //break;
 
             case 'm':
+#ifndef _WIN32
                 multi_mode = true;
+#endif
+                break;
+
+            case 'n':
+                no_restore_bkup = true;
                 break;
 
             case 's':
@@ -391,6 +403,7 @@ int main( int argc, char **argv )
                 std::cout << "JD " << ENVIRONMENT::get_jdversion() << ", " <<
                 ENVIRONMENT::get_jdcopyright() << "\n"
                 "configure: " << ENVIRONMENT::get_configure_args( ENVIRONMENT::CONFIGURE_FULL ) << std::endl;
+                exit( 0 );
                 break;
 
             default:
@@ -406,7 +419,9 @@ int main( int argc, char **argv )
             url = argv[ optind ];
         }
         // -m 、-s でなく、URLを含まない引数だけの場合は終了
-        else if( optind > 1 && ! ( multi_mode || skip_setupdiag || logfile_mode ) ) return 0;
+        else if( optind > 1 && ! ( multi_mode || no_restore_bkup || skip_setupdiag || logfile_mode ) ){
+            usage( EXIT_FAILURE );
+        }
     }
     /*---------------------------------------------------------------*/
 
@@ -503,12 +518,12 @@ int main( int argc, char **argv )
 
     // メッセージをログファイルに出力
     if( logfile_mode && CACHE::mkdir_logroot() ){
-        freopen( to_locale_cstr( CACHE::path_msglog() ), "ab", stdout );
-        freopen( to_locale_cstr( CACHE::path_msglog() ), "ab", stderr );
+        FILE *tmp; // warning 消し
+        tmp = freopen( to_locale_cstr( CACHE::path_msglog() ), "ab", stdout );
+        tmp = freopen( to_locale_cstr( CACHE::path_msglog() ), "ab", stderr );
     }
 
     /*--- IOMonitor -------------------------------------------------*/
-#ifndef _WIN32
     CORE::IOMonitor iomonitor;
 
     // FIFOの状態をチェックする
@@ -537,42 +552,35 @@ int main( int argc, char **argv )
             if( ret != Gtk::RESPONSE_YES ) return 0;
         }
     }
-    // FIFOに問題がある
+    // FIFOに問題がある(FATで作成出来ないなど)
     else
     {
-        Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( CACHE::path_lock() + "の作成またはオープンに問題があります。起動しますか？",
-                                                            false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-        int ret = mdiag->run();
-        delete mdiag;
-        if( ret != Gtk::RESPONSE_YES ) return 1;
-    }
-#endif
-
-    /*---------------------------------------------------------------*/
-#ifdef _WIN32
-    // 多重起動の確認
-    HANDLE hJdLock = NULL;
-    hJdLock = CreateSemaphore(NULL, LONG_MAX, LONG_MAX, "JdForWindowsLockObject"); //2147483647
-    if( ! multi_mode )
-    {
-        if( GetLastError() == ERROR_ALREADY_EXISTS )
+        if( CONFIG::get_show_diag_fifo_error() )
         {
-            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( "JDは既に起動しています。起動しますか？",
+            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( CACHE::path_lock() + "の作成またはオープンに問題があります。このまま起動しますか？",
                                                                 false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-            int ret = mdiag->run();
+
+            Gtk::CheckButton chk_button( "今後表示しない" );
+            mdiag->get_vbox()->pack_start( chk_button, Gtk::PACK_SHRINK );
+            chk_button.show();
+
+            const int ret = mdiag->run();
+
+            CONFIG::set_show_diag_fifo_error( ! chk_button.get_active() );
+
             delete mdiag;
+
             if( ret != Gtk::RESPONSE_YES )
             {
-                CloseHandle( hJdLock );
-                return 0;
+                CONFIG::save_conf();
+                return 1;
             }
         }
     }
-#endif
-    /*---------------------------------------------------------------*/
 
+    /*---------------------------------------------------------------*/
     // バックアップファイル復元
-    restore_bkup();
+    restore_bkup( no_restore_bkup );
 
     Win_Main = new JDWinMain( init, skip_setupdiag );
     if( Win_Main ){
@@ -586,12 +594,6 @@ int main( int argc, char **argv )
 #ifdef USE_XSMP
     xsmp_session_end( &xsmpdata );
 #endif
-#ifdef _WIN32
-    if( hJdLock != NULL )
-    {
-        CloseHandle( hJdLock );
-    }
-#endif
 
     JDLIB::deinit_ssl();
 
