@@ -81,6 +81,7 @@ int board_col_new;
 int board_col_since;
 int board_col_write;
 int board_col_speed;
+int board_col_diff;
 
 int board_col_since_time;
 int board_col_write_time;
@@ -99,6 +100,8 @@ bool show_article_toolbar;
 bool show_board_tab;
 bool show_article_tab;
 
+bool show_main_statbar;
+
 int win_focused_admin;
 int win_focused_admin_sidebar;
 
@@ -134,6 +137,8 @@ bool shown_win_main = false;
 bool shown_win_img = false;
 bool shown_win_mes = false;
 
+bool full_win_main = false;
+
 bool dialog_shown = false;
 
 bool embedded_img;
@@ -170,6 +175,7 @@ const int SESSION::parse_item( const std::string& item_name )
     else if( item_name == ITEM_NAME_HISTVIEW ) item = ITEM_HISTVIEW;
     else if( item_name == ITEM_NAME_HIST_BOARDVIEW ) item = ITEM_HIST_BOARDVIEW;
     else if( item_name == ITEM_NAME_HIST_CLOSEVIEW ) item = ITEM_HIST_CLOSEVIEW;
+    else if( item_name == ITEM_NAME_HIST_CLOSEIMGVIEW ) item = ITEM_HIST_CLOSEIMGVIEW;
     else if( item_name == ITEM_NAME_ARTICLEVIEW ) item = ITEM_ARTICLEVIEW;
     else if( item_name == ITEM_NAME_IMAGEVIEW ) item = ITEM_IMAGEVIEW;
     else if( item_name == ITEM_NAME_URL ) item = ITEM_URL;
@@ -186,6 +192,7 @@ const int SESSION::parse_item( const std::string& item_name )
     else if( item_name == ITEM_NAME_SINCE ) item = ITEM_SINCE;
     else if( item_name == ITEM_NAME_LASTWRITE ) item = ITEM_LASTWRITE;
     else if( item_name == ITEM_NAME_SPEED ) item = ITEM_SPEED;
+    else if( item_name == ITEM_NAME_DIFF ) item = ITEM_DIFF;
 
     else if( item_name == ITEM_NAME_WRITEMSG ) item = ITEM_WRITEMSG;
     else if( item_name == ITEM_NAME_OPENBOARD ) item = ITEM_OPENBOARD;
@@ -196,7 +203,7 @@ const int SESSION::parse_item( const std::string& item_name )
     else if( item_name == ITEM_NAME_DRAWOUT ) item = ITEM_DRAWOUT;
     else if( item_name == ITEM_NAME_RELOAD ) item = ITEM_RELOAD;
     else if( item_name == ITEM_NAME_STOPLOADING ) item = ITEM_STOPLOADING;
-    else if( item_name == ITEM_NAME_FAVORITE ) item = ITEM_FAVORITE;
+    else if( item_name == ITEM_NAME_APPENDFAVORITE ) item = ITEM_APPENDFAVORITE;
     else if( item_name == ITEM_NAME_FAVORITE_ARTICLE ) item = ITEM_FAVORITE_ARTICLE;
     else if( item_name == ITEM_NAME_CHECK_UPDATE_ROOT ) item = ITEM_CHECK_UPDATE_ROOT;
     else if( item_name == ITEM_NAME_CHECK_UPDATE_OPEN_ROOT ) item = ITEM_CHECK_UPDATE_OPEN_ROOT;
@@ -209,8 +216,8 @@ const int SESSION::parse_item( const std::string& item_name )
 
     else if( item_name == ITEM_NAME_DELETE ) item = ITEM_DELETE;
     else if( item_name == ITEM_NAME_QUIT ) item = ITEM_QUIT;
-    else if( item_name == ITEM_NAME_PREVVIEW ) item = ITEM_PREVVIEW;
-    else if( item_name == ITEM_NAME_NEXTVIEW ) item = ITEM_NEXTVIEW;
+    else if( item_name == ITEM_NAME_BACK ) item = ITEM_BACK;
+    else if( item_name == ITEM_NAME_FORWARD ) item = ITEM_FORWARD;
     else if( item_name == ITEM_NAME_LOCK ) item = ITEM_LOCK;
     else if( item_name == ITEM_NAME_LIVE ) item = ITEM_LIVE;
 
@@ -232,6 +239,7 @@ const int SESSION::parse_item( const std::string& item_name )
     else if( item_name == ITEM_NAME_ABONE_ARTICLE ) item = ITEM_ABONE_ARTICLE;
     else if( item_name == ITEM_NAME_QUOTE_SELECTION ) item = ITEM_QUOTE_SELECTION;
     else if( item_name == ITEM_NAME_OPEN_BROWSER ) item = ITEM_OPEN_BROWSER;
+    else if( item_name == ITEM_NAME_OPEN_CACHE_BROWSER ) item = ITEM_OPEN_CACHE_BROWSER;
     else if( item_name == ITEM_NAME_USER_COMMAND ) item = ITEM_USER_COMMAND;
     else if( item_name == ITEM_NAME_ETC ) item = ITEM_ETC;
     else if( item_name == ITEM_NAME_SAVE_DAT ) item = ITEM_SAVE_DAT;
@@ -322,6 +330,7 @@ void SESSION::init_session()
     width_win_main = cf.get_option_int( "width", 800, 80, 8192 );
     height_win_main = cf.get_option_int( "height", 600, 60, 8192 );
     maximized_win_main = cf.get_option_bool( "maximized", false );
+    full_win_main = cf.get_option_bool( "full_win_main", false );
 
     win_show_sidebar = cf.get_option_bool( "show_sidebar", true );
 
@@ -337,6 +346,8 @@ void SESSION::init_session()
     show_board_tab = cf.get_option_bool( "show_board_tab", true );
     show_article_tab = cf.get_option_bool( "show_article_tab", true );
 
+    show_main_statbar = cf.get_option_bool( "show_main_statbar", true );
+
     win_focused_admin = cf.get_option_int( "focused_admin", FOCUS_NOT, 0, FOCUS_NUM -1 );
     win_focused_admin_sidebar = cf.get_option_int( "focused_admin_sidebar", FOCUS_NOT, 0, FOCUS_NUM -1 );
 
@@ -402,6 +413,7 @@ void SESSION::init_session()
     board_col_since = cf.get_option_int( "col_since", 70, 4, 8192 );
     board_col_write = cf.get_option_int( "col_write", 70, 4, 8192 );
     board_col_speed = cf.get_option_int( "col_speed", 45, 4, 8192 );
+    board_col_diff = cf.get_option_int( "col_diff", 45, 4, 8192 );
 
     // スレ一覧の since の表示モード
     board_col_since_time = cf.get_option_int( "col_since_time", MISC::TIME_NORMAL, 0, MISC::TIME_NUM-1 );
@@ -486,6 +498,7 @@ void SESSION::init_session()
               << board_col_since << std::endl
               << board_col_write << std::endl
               << board_col_speed << std::endl
+              << board_col_diff << std::endl
 
               << "embedded_mes = " << embedded_mes << std::endl
               << "close_mes = " << close_mes << std::endl
@@ -556,6 +569,7 @@ void SESSION::save_session()
         << "width = " << width_win_main << std::endl
         << "height = " << height_win_main << std::endl
         << "maximized = " << maximized_win_main << std::endl
+        << "full_win_main = " << full_win_main << std::endl
         << "show_main_toolbar = " << show_main_toolbar << std::endl
         << "toolbar_pos = " << win_toolbar_pos << std::endl
         << "show_bbslist_toolbar = " << show_bbslist_toolbar << std::endl
@@ -565,6 +579,7 @@ void SESSION::save_session()
         << "show_article_tab = " << show_article_tab << std::endl
         << "show_sidebar = " << win_show_sidebar << std::endl
         << "show_menubar = " << win_show_menubar << std::endl
+        << "show_main_statbar = " << show_main_statbar << std::endl
         << "focused_admin = " << win_focused_admin << std::endl
         << "focused_admin_sidebar = " << win_focused_admin_sidebar << std::endl
 
@@ -608,6 +623,7 @@ void SESSION::save_session()
         << "col_since = " << board_col_since << std::endl
         << "col_write = " << board_col_write << std::endl
         << "col_speed = " << board_col_speed << std::endl
+        << "col_diff = " << board_col_diff << std::endl
 
         << "col_since_time = " << board_col_since_time << std::endl
         << "col_write_time = " << board_col_write_time << std::endl
@@ -689,6 +705,9 @@ void SESSION::set_show_board_tab( const bool show ){ show_board_tab = show; }
 const bool SESSION::get_show_article_tab(){ return show_article_tab; }
 void SESSION::set_show_article_tab( const bool show ){ show_article_tab = show; }
 
+const bool SESSION::get_show_main_statbar(){ return show_main_statbar; }
+void SESSION::set_show_main_statbar( const bool show ){ show_main_statbar = show; }
+
 const int SESSION::focused_admin(){ return win_focused_admin; }
 void SESSION::set_focused_admin( const int admin ){ win_focused_admin = admin; }
 const int SESSION::focused_admin_sidebar(){ return win_focused_admin_sidebar; }
@@ -773,6 +792,11 @@ const bool SESSION::is_shown_win_mes(){ return shown_win_mes; }
 void SESSION::set_shown_win_mes( const bool set ){ shown_win_mes = set; }
 
 
+// windowがフルスクリーンか
+const bool SESSION::is_full_win_main(){ return full_win_main; }
+void SESSION::set_full_win_main( const bool set ){ full_win_main = set; }
+
+
 // ダイアログ表示中
 const bool SESSION::is_dialog_shown(){ return dialog_shown; }
 void SESSION::set_dialog_shown( const bool set ){ dialog_shown = set; }
@@ -879,7 +903,7 @@ const std::string SESSION::get_items_article_toolbar_default_str()
     ITEM_NAME_SEARCH + std::string ( " " ) +
     ITEM_NAME_RELOAD + std::string ( " " ) +
     ITEM_NAME_STOPLOADING + std::string ( " " ) +
-    ITEM_NAME_FAVORITE + std::string ( " " ) +
+    ITEM_NAME_APPENDFAVORITE + std::string ( " " ) +
     ITEM_NAME_DELETE + std::string ( " " ) +
     ITEM_NAME_QUIT;
 }
@@ -901,7 +925,7 @@ const std::string SESSION::get_items_board_toolbar_default_str()
     ITEM_NAME_SEARCH_PREV + std::string ( " " ) +
     ITEM_NAME_RELOAD + std::string ( " " ) +
     ITEM_NAME_STOPLOADING + std::string ( " " ) +
-    ITEM_NAME_FAVORITE + std::string ( " " ) +
+    ITEM_NAME_APPENDFAVORITE + std::string ( " " ) +
     ITEM_NAME_DELETE + std::string ( " " ) +
     ITEM_NAME_QUIT;
 }
@@ -1024,6 +1048,7 @@ const int SESSION::col_new(){ return board_col_new; }
 const int SESSION::col_since(){ return board_col_since; }
 const int SESSION::col_write(){ return board_col_write; }
 const int SESSION::col_speed(){ return board_col_speed; }
+const int SESSION::col_diff(){ return board_col_diff; }
 
 // スレ一覧の since の表示モード
 const int SESSION::get_col_since_time() { return board_col_since_time; }
@@ -1056,6 +1081,7 @@ void SESSION::set_col_new( const int width ){ board_col_new = width; }
 void SESSION::set_col_since( const int width ){ board_col_since = width; }
 void SESSION::set_col_write( const int width ){ board_col_write = width; }
 void SESSION::set_col_speed( const int width ){ board_col_speed = width; }
+void SESSION::set_col_diff( const int width ){ board_col_diff = width; }
 
 
 // 現在開いているarticle の ARTICLE::DrawAreaBase
