@@ -25,6 +25,7 @@
 #include "control/controlid.h"
 
 #include "command.h"
+#include "prefdiagfactory.h"
 
 #include <gtk/gtk.h>  // gtk_separator_tool_item_set_draw
 #include <gtk/gtkbutton.h>
@@ -108,8 +109,7 @@ void ToolBar::set_view( SKELETON::View* view )
 
     // ラベル表示更新
     set_label( view->get_label() );
-    if( view->is_broken() ) set_broken();
-    if( view->is_old() ) set_old();
+    if( view->is_broken() || view->is_old() ) set_color( view->get_color() );
 
     // 閉じるボタンの表示更新
     if( m_button_close ){
@@ -120,6 +120,8 @@ void ToolBar::set_view( SKELETON::View* view )
         if( m_button_lock ) m_button_lock->set_active( view->is_locked() );
     }
 
+    if( m_button_write ) m_button_write->set_sensitive( view->is_writeable() );
+
     if( m_entry_search ) m_entry_search->set_text( view->get_search_query() );
 
     if( m_label_board ) m_label_board->set_text( DBTREE::board_name( get_url() ) );
@@ -315,50 +317,33 @@ void ToolBar::set_label( const std::string& label )
 {
     if( ! m_ebox_label ) return;
 
-    // ラベルの文字色と背景色を戻す
-    if( m_ebox_label->get_visible_window() ){
-        m_ebox_label->set_visible_window( false );
-        m_label->unset_fg( Gtk::STATE_NORMAL );
-    }
-
     m_label->set_text( label );
     if( m_tool_label ) set_tooltip( *m_tool_label, label );
+    set_color( "" );
 }
 
 
-// viewが壊れている
-void ToolBar::set_broken()
+void ToolBar::set_color( const std::string& color )
 {
     if( ! m_ebox_label ) return;
 
-#ifdef _DEBUG
-    std::cout << "ToolBar::set_broken\n";
-#endif
+    if( color.empty() ){
 
-    m_ebox_label->set_visible_window( true );
-    m_label->modify_fg( Gtk::STATE_NORMAL, Gdk::Color( "white" ) );
-    m_ebox_label->modify_bg( Gtk::STATE_NORMAL, Gdk::Color( "red" ) );
-    m_ebox_label->modify_bg( Gtk::STATE_ACTIVE, Gdk::Color( "red" ) );
+        if( m_ebox_label->get_visible_window() ){
+            m_ebox_label->set_visible_window( false );
+            m_label->unset_fg( Gtk::STATE_NORMAL );
+        }
+    }
+    else{
+
+        m_ebox_label->set_visible_window( true );
+        m_label->modify_fg( Gtk::STATE_NORMAL, Gdk::Color( "white" ) );
+        m_ebox_label->modify_bg( Gtk::STATE_NORMAL, Gdk::Color( color ) );
+        m_ebox_label->modify_bg( Gtk::STATE_ACTIVE, Gdk::Color( color ) );
+    }
 }
 
 
-// viewが古い
-void ToolBar::set_old()
-{
-    if( ! m_ebox_label ) return;
-
-#ifdef _DEBUG
-    std::cout << "ToolBar::set_old\n";
-#endif
-
-    m_ebox_label->set_visible_window( true );
-    m_label->modify_fg( Gtk::STATE_NORMAL, Gdk::Color( "white" ) );
-    m_ebox_label->modify_bg( Gtk::STATE_NORMAL, Gdk::Color( "blue" ) );
-    m_ebox_label->modify_bg( Gtk::STATE_ACTIVE, Gdk::Color( "blue" ) );
-}
-
-
-
 // 検索バー
 Gtk::Toolbar* ToolBar::get_searchbar()
 {
@@ -419,7 +404,7 @@ void ToolBar::close_searchbar()
 Gtk::ToolItem* ToolBar::get_button_open_searchbar()
 {
     if( ! m_button_open_searchbar ){
-        m_button_open_searchbar = Gtk::manage( new SKELETON::ImgToolButton( Gtk::Stock::FIND ) );
+        m_button_open_searchbar = Gtk::manage( new SKELETON::ImgToolButton( ICON::SEARCH ) );
 
         std::string tooltip = "検索バーを開く  " + CONTROL::get_str_motions( CONTROL::Search );
         set_tooltip( *m_button_open_searchbar, tooltip );
@@ -432,7 +417,7 @@ Gtk::ToolItem* ToolBar::get_button_open_searchbar()
 Gtk::ToolItem* ToolBar::get_button_close_searchbar()
 {
     if( ! m_button_close_searchbar ){
-        m_button_close_searchbar = Gtk::manage( new SKELETON::ImgToolButton( Gtk::Stock::UNDO ) );
+        m_button_close_searchbar = Gtk::manage( new SKELETON::ImgToolButton( ICON::CLOSE_SEARCH ) );
         set_tooltip( *m_button_close_searchbar, CONTROL::get_label_motions( CONTROL::CloseSearchBar ) );
         m_button_close_searchbar->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_toggle_searchbar ) );
     }
@@ -554,7 +539,7 @@ void ToolBar::focus_entry_search()
 Gtk::ToolButton* ToolBar::get_button_up_search()
 {
     if( ! m_button_up_search ){
-        m_button_up_search = Gtk::manage( new ImgToolButton( Gtk::Stock::GO_UP ) );
+        m_button_up_search = Gtk::manage( new ImgToolButton( ICON::SEARCH_PREV ) );
         set_tooltip( *m_button_up_search, CONTROL::get_label_motions( CONTROL::SearchPrev ) );
 
         m_button_up_search->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_up_search ) );
@@ -583,7 +568,7 @@ void ToolBar::slot_clicked_up_search()
 Gtk::ToolButton* ToolBar::get_button_down_search()
 {
     if( ! m_button_down_search ){
-        m_button_down_search = Gtk::manage( new ImgToolButton( Gtk::Stock::GO_DOWN ) );
+        m_button_down_search = Gtk::manage( new ImgToolButton( ICON::SEARCH_NEXT ) );
         set_tooltip( *m_button_down_search, CONTROL::get_label_motions( CONTROL::SearchNext ) );
 
         m_button_down_search->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_down_search ) );
@@ -619,6 +604,9 @@ Gtk::ToolItem* ToolBar::get_button_board()
         std::vector< std::string > menu;
         menu.push_back( "開く" );
         menu.push_back( "再読み込みして開く" );
+        menu.push_back( "separator" );
+        menu.push_back( "ローカルルールを表示" );
+        menu.push_back( "板のプロパティを表示" );
         m_button_board->get_button()->append_menu( menu );
         m_button_board->get_button()->signal_selected().connect( sigc::mem_fun(*this, &ToolBar::slot_menu_board ) );
         m_button_board->get_button()->signal_button_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_open_board ) );
@@ -644,8 +632,18 @@ void ToolBar::slot_menu_board( int i )
 {
     if( ! m_enable_slot ) return;
 
+    SKELETON::PrefDiag* pref = NULL;
+
+    // ToolBar::get_button_board()で作成したメニューの順番に内容を合わせる
     if( i == 0 ) slot_open_board();
     else if( i == 1 ) CORE::core_set_command( "open_board", DBTREE::url_subject( get_url() ), "true" );
+    else if( i == 3 ) pref = CORE::PrefDiagFactory( CORE::get_mainwindow(), CORE::PREFDIAG_BOARD, DBTREE::url_subject( get_url() ), "show_localrule" );
+    else if( i == 4 ) pref = CORE::PrefDiagFactory( CORE::get_mainwindow(), CORE::PREFDIAG_BOARD, DBTREE::url_subject( get_url() )  );
+
+    if( pref ){
+        pref->run();
+        delete pref;
+    }
 }
 
 
@@ -723,7 +721,7 @@ bool ToolBar::slot_focusout_write_button( GdkEventFocus* event )
 Gtk::ToolItem* ToolBar::get_button_reload()
 {
     if( ! m_button_reload ){
-        m_button_reload = Gtk::manage( new ImgToolButton( Gtk::Stock::REFRESH ) );
+        m_button_reload = Gtk::manage( new ImgToolButton( ICON::RELOAD ) );
         set_tooltip( *m_button_reload, CONTROL::get_label_motions( CONTROL::Reload ) );
 
         m_button_reload->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_reload ) );
@@ -752,7 +750,7 @@ void ToolBar::slot_clicked_reload()
 Gtk::ToolItem* ToolBar::get_button_stop()
 {
     if( ! m_button_stop ){
-        m_button_stop = Gtk::manage( new ImgToolButton( Gtk::Stock::STOP ) );
+        m_button_stop = Gtk::manage( new ImgToolButton( ICON::STOPLOADING ) );
         set_tooltip( *m_button_stop, CONTROL::get_label_motions( CONTROL::StopLoading ) );
 
         m_button_stop->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_stop ) );
@@ -781,7 +779,7 @@ void ToolBar::slot_clicked_stop()
 Gtk::ToolButton* ToolBar::get_button_close()
 {
     if( ! m_button_close ){
-        m_button_close = Gtk::manage( new ImgToolButton( Gtk::Stock::CLOSE ) );
+        m_button_close = Gtk::manage( new ImgToolButton( ICON::QUIT ) );
         set_tooltip( *m_button_close, CONTROL::get_label_motions( CONTROL::Quit ) );
 
         m_button_close->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_close ) );
@@ -822,7 +820,7 @@ void ToolBar::slot_clicked_close()
 Gtk::ToolItem* ToolBar::get_button_delete()
 {
     if( ! m_button_delete ){
-        m_button_delete = Gtk::manage( new ImgToolButton( Gtk::Stock::DELETE ) );
+        m_button_delete = Gtk::manage( new ImgToolButton( ICON::DELETE ) );
         set_tooltip( *m_button_delete, CONTROL::get_label_motions( CONTROL::Delete ) );
 
         m_button_delete->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_delete ) );
@@ -851,7 +849,7 @@ void ToolBar::slot_clicked_delete()
 Gtk::ToolItem* ToolBar::get_button_favorite()
 {
     if( ! m_button_favorite ){
-        m_button_favorite = Gtk::manage( new ImgToolButton( Gtk::Stock::COPY ) );
+        m_button_favorite = Gtk::manage( new ImgToolButton( ICON::APPENDFAVORITE ) );
         set_tooltip( *m_button_favorite, CONTROL::get_label_motions( CONTROL::AppendFavorite ) );
 
         m_button_favorite->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_favorite ) );
@@ -880,7 +878,7 @@ void ToolBar::slot_clicked_favorite()
 Gtk::ToolButton* ToolBar::get_button_undo()
 {
     if( ! m_button_undo ){
-        m_button_undo = Gtk::manage( new SKELETON::ImgToolButton( Gtk::Stock::UNDO ) );
+        m_button_undo = Gtk::manage( new SKELETON::ImgToolButton( ICON::UNDO ) );
         m_button_undo->set_sensitive( false );
         set_tooltip( *m_button_undo, CONTROL::get_label_motions( CONTROL::Undo ) );
     }
@@ -895,7 +893,7 @@ Gtk::ToolButton* ToolBar::get_button_undo()
 Gtk::ToolButton* ToolBar::get_button_redo()
 {
     if( ! m_button_redo ){
-        m_button_redo = Gtk::manage( new SKELETON::ImgToolButton( Gtk::Stock::REDO ) );
+        m_button_redo = Gtk::manage( new SKELETON::ImgToolButton( ICON::REDO ) );
         m_button_redo->set_sensitive( false );
         set_tooltip( *m_button_redo, CONTROL::get_label_motions( CONTROL::Redo ) );
     }
@@ -997,7 +995,7 @@ void ToolBar::slot_selected_forward( const int i )
 Gtk::ToolItem* ToolBar::get_button_lock()
 {
     if( ! m_button_lock ){
-        m_button_lock = Gtk::manage( new SKELETON::ImgToggleToolButton( Gtk::Stock::NO ) );
+        m_button_lock = Gtk::manage( new SKELETON::ImgToggleToolButton( ICON::LOCK ) );
         set_tooltip( *m_button_lock, CONTROL::get_label_motions( CONTROL::Lock ) );
         m_button_lock->set_label( CONTROL::get_label( CONTROL::Lock ) );
         m_button_lock->signal_clicked().connect( sigc::mem_fun( *this, &ToolBar::slot_lock_clicked ) );
